==> zio-aws-lightsail_2.12-5.17.206.1-sources.jar: zio/aws/lightsail/model/CookieObject.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CookieObject(
    option: Optional[zio.aws.lightsail.model.ForwardValues] = Optional.Absent,
    cookiesAllowList: Optional[Iterable[String]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.CookieObject = {
    import CookieObject.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.CookieObject
      .builder()
      .optionallyWith(option.map(value => value.unwrap))(_.option)
      .optionallyWith(
        cookiesAllowList.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.cookiesAllowList)
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.CookieObject.ReadOnly =
    zio.aws.lightsail.model.CookieObject.wrap(buildAwsValue())
}
object CookieObject {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.CookieObject
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.CookieObject =
      zio.aws.lightsail.model.CookieObject(
        option.map(value => value),
        cookiesAllowList.map(value => value)
      )
    def option: Optional[zio.aws.lightsail.model.ForwardValues]
    def cookiesAllowList: Optional[List[String]]
    def getOption: ZIO[Any, AwsError, zio.aws.lightsail.model.ForwardValues] =
      AwsError.unwrapOptionField("option", option)
    def getCookiesAllowList: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("cookiesAllowList", cookiesAllowList)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.CookieObject
  ) extends zio.aws.lightsail.model.CookieObject.ReadOnly {
    override val option: Optional[zio.aws.lightsail.model.ForwardValues] =
      zio.aws.core.internal
        .optionalFromNullable(impl.option())
        .map(value => zio.aws.lightsail.model.ForwardValues.wrap(value))
    override val cookiesAllowList: Optional[List[String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cookiesAllowList())
        .map(value =>
          value.asScala.map { item =>
            item: String
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.CookieObject
  ): zio.aws.lightsail.model.CookieObject.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lightsail_2.13-5.17.104.4-sources.jar: zio/aws/lightsail/model/CookieObject.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CookieObject(
    option: Option[zio.aws.lightsail.model.ForwardValues] = None,
    cookiesAllowList: Option[Iterable[String]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.CookieObject = {
    import CookieObject.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.CookieObject
      .builder()
      .optionallyWith(option.map(value => value.unwrap))(_.option)
      .optionallyWith(
        cookiesAllowList.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.cookiesAllowList)
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.CookieObject.ReadOnly =
    zio.aws.lightsail.model.CookieObject.wrap(buildAwsValue())
}
object CookieObject {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.CookieObject
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.CookieObject =
      zio.aws.lightsail.model.CookieObject(
        option.map(value => value),
        cookiesAllowList.map(value => value)
      )
    def option: Option[zio.aws.lightsail.model.ForwardValues]
    def cookiesAllowList: Option[List[String]]
    def getOption: ZIO[Any, AwsError, zio.aws.lightsail.model.ForwardValues] =
      AwsError.unwrapOptionField("option", option)
    def getCookiesAllowList: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("cookiesAllowList", cookiesAllowList)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.CookieObject
  ) extends zio.aws.lightsail.model.CookieObject.ReadOnly {
    override val option: Option[zio.aws.lightsail.model.ForwardValues] = scala
      .Option(impl.option())
      .map(value => zio.aws.lightsail.model.ForwardValues.wrap(value))
    override val cookiesAllowList: Option[List[String]] = scala
      .Option(impl.cookiesAllowList())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.CookieObject
  ): zio.aws.lightsail.model.CookieObject.ReadOnly = new Wrapper(impl)
}
